@@ -161,8 +161,7 @@ test_that("Only reasonable hyperparameters pass checks", {
     v_folds = v_folds,
     center = center,
     scale = scale,
-    parallel = parallel,
-    true_cov_mat = Sigma
+    parallel = parallel
   ))
   expect_error(checkArgs(
     dat = dat,
@@ -596,45 +595,6 @@ test_that("Only reasonable hyperparameters pass checks", {
     scale = scale,
     parallel = parallel
   ))
-  expect_error(checkArgs(
-    dat = dat,
-    estimators = estimators,
-    estimator_params = estimator_params,
-    cv_loss = cv_loss,
-    cv_scheme = cv_scheme,
-    mc_split = mc_split,
-    v_folds = v_folds,
-    center = center,
-    scale = scale,
-    parallel = parallel,
-    true_cov_mat = dat
-  ))
-  expect_error(checkArgs(
-    dat = dat,
-    estimators = estimators,
-    estimator_params = estimator_params,
-    cv_loss = cv_loss,
-    cv_scheme = cv_scheme,
-    mc_split = mc_split,
-    v_folds = v_folds,
-    center = center,
-    scale = scale,
-    parallel = parallel,
-    true_cov_mat = Sigma[1:50, 1:20]
-  ))
-  expect_error(checkArgs(
-    dat = dat,
-    estimators = estimators,
-    estimator_params = estimator_params,
-    cv_loss = cv_loss,
-    cv_scheme = cv_scheme,
-    mc_split = mc_split,
-    v_folds = v_folds,
-    center = center,
-    scale = scale,
-    parallel = parallel,
-    true_cov_mat = as.character(Sigma)
-  ))
 })
 
 test_that("Only reasonable CV schemes pass checks", {
